@@ -2,18 +2,18 @@
   filtersylpheed.h  -  Sylpheed maildir mail import
 
   SPDX-FileCopyrightText: 2005 Danny Kukawka <danny.kukawka@web.de>
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MAILIMPORTER_FILTER_SYLPHEED_H
-#define MAILIMPORTER_FILTER_SYLPHEED_H
+#pragma once
 
 #include <QHash>
 
 #include "filters.h"
-namespace MailImporter {
+namespace MailImporter
+{
 class FilterSylpheedPrivate;
 /**
  * Imports Sylpheed mail folder with maildir format recursively, recreating the folder structure.
@@ -36,8 +36,8 @@ public:
     Q_REQUIRED_RESULT virtual bool excludeFile(const QString &file);
     virtual QString defaultInstallFolder() const;
     virtual QString markFile() const;
-private:
 
+private:
     void importDirContents(const QString &);
     void importFiles(const QString &);
     void processDirectory(const QString &path);
@@ -48,4 +48,3 @@ private:
 };
 }
 
-#endif
